package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@(!`0D```````````(`/@`!````T!U```````!``````````#BG````
M`````````$``.``(`$``&P`:``8````%````0`````````!``$```````$``
M0```````P`$```````#``0````````@``````````P````0``````@``````
M```"0`````````)````````5`````````!4``````````0`````````!````
M!0````````````````!``````````$```````)R7````````G)<`````````
M`"````````$````&`````*``````````H&````````"@8```````9`0`````
M``"("0``````````(````````@````8````HH````````"B@8```````**!@
M```````0`@```````!`"````````"``````````$````!````!@"````````
M&`)````````8`D```````!@`````````&``````````$`````````%#E=&0$
M````D),```````"0DT```````)"30```````Q`````````#$``````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````"``````````O;&EB97AE8R]L9"UE;&8N<V\N,0`````(````
M!`````$```!&<F5E0E-$`''##0!#````7``````````'`````````#D````Q
M``````````````!-`````````#(```!0````(@```",````8`````````#L`
M``!7`````````#,````\``````````````!(````!0```$H````6````1@``
M`"T```!!````2P```!4`````````5``````````@````+```````````````
M$````"D`````````.``````````N````6````!D````>````50````````!'
M````3```````````````5@```"@````=````+P`````````Z````40``````
M```V`````0```$`````J````*P```$(`````````````````````````````
M`````````````````#\``````````````$D`````````````````````````
M````````````````!`````P```````````````````!3````````````````
M````"0`````````<````"@```$\`````````0P```````````````@```#T`
M```7````&P````T````3````$@```"$````1````)P```!0`````````#P``
M````````````"````!H````T````'P```#X`````````10````````!9````
M4@````8````#`````````"8```!:``````````````!.````#@``````````
M``````````L````D`````````#``````````1``````````U````````````
M```````````````````W`````````%L````E```````````````1````/0``
M``0````(````(`P```5`!(`H`$``D(8!B,(A`2!)``0;B((X2;H$!@@]````
M/P```$,```!'````2````$X```!/````4````%(```!3`````````%0```!6
M````6````%D`````````6P```+Q0=IY[\$IKZM/O#F[%WQ_.WD<M:W^:?"[%
MF[;49-1\(/_D#KF-\0[9<5@<XD?&`;(!BV_"Y3\LNN.2?/+;TQW[H6Q@A_F<
M@6>OS&9"1=7LB0=PT\G5LG$S8MOM5J2;EJ?=HVM^J9R;YQ4#@^&G`@H*BA!7
MH^#[22%B9`<```````````````````````````````#"`0``$@``````````
M````(0$````````D`0``$@``````````````%0````````#+`P``$@``````
M````````'@````````"K`0``$@``````````````B@8```````!%`@``$@``
M``````````````````````!/````$@``````````````K``````````-````
M(`````````````````````````!K`0``$@``````````````(00```````#&
M````$@``````````````4P$```````!;`0``$@``````````````5P``````
M``!-`0``$@``````````````=`$````````#`P``$@``````````````+P``
M``````#``@``$@``````````````#``````````2`P``$@``````````````
M```````````*`P``$@``````````````;``````````E`@``$@``````````
M``````````````#)`0``$@``````````````5`$```````!5`@``$@``````
M`````````@````````!.`@``$@``````````````50````````!N`@``$@``
M````````````V0````````#J`@``$@``````````````D``````````P````
M$@``````````````2@````````!T````$@``````````````>0`````````X
M`@``$@``````````````9P`````````^`@``$@``````````````]```````
M```V````$@``````````````<0`````````(`0``$@``````````````B0``
M``````"B````$@``````````````2P@````````=`@``$@``````````````
M(0`````````D`@``$@````````````````````````!?`@``$@``````````
M``````````````!^`@``$@````````````````````````"S`@``$@``````
M``````````````````"4`@``$@``````````````-`````````#F````$@``
M````````````IP$```````"-`0``$@``````````````L`$````````A````
M$@``````````````T`````````!_`0``$@``````````````1AH````````[
M````$@``````````````10````````#\`@``$@``````````````````````
M``"<`@``$@``````````````3`````````#'`@``$@``````````````#```
M```````N`0``$@``````````````_0````````!F`@``$@``````````````
MCQ````````!4````$@``````````````,0````````"K`@``$@``````````
M````"@`````````J`@``$@``````````````2@````````"Q````$@``````
M````````I0`````````Q`@``$@``````````````?`````````"Y`@``$@``
M``````````````````````"$`@``$@``````````````5`````````"V`0``
M$@``````````````.P`````````%`P``$@``````````````+P`````````I
M`0``$@``````````````#0<```````!T`0``$@``````````````<P``````
M``""````$@``````````````G`````````!V`@``$@``````````````2@``
M``````"+`@``$@``````````````FP````````"D`@``$@``````````````
M?@````````#4````$@``````````````X0<````````2`@``$0`7`$"D8```
M````"`````````";`0``$@```'P;0```````^`$```````#U````$@`.`+12
M0`````````````````#4`P``$@`-`*`_0```````;0````````#H`P``$@`-
M``!$0```````/@H````````K!```$@`-`!!`0```````&`(```````!5`P``
M$@`-`'`Y0```````!0````````!S`P``$@`-`$!.0```````P`,````````'
M!```$@`-`#!"0```````Q@$```````#B`P``$@`+`,@90```````````````
M```@`P``$`#Q_V2D8`````````````````!F`P``$@`-```?0```````-```
M``````")`P``$@`-`(`V0```````30````````#@`P``$@`-``!20```````
M*@`````````L`P``$`#Q_XBI8`````````````````#4`0``$0`8`/"D8```
M````$P````````#U`P``$@`-`*`[0```````%P$```````"1````$@```(P;
M0```````2@````````"M`P``$@`-`+`^0```````X@`````````9`P``$`#Q
M_V2D8``````````````````4!```$0`7`%BD8```````"``````````Z`0``
M$@```$P:0```````2@`````````E`P``$@`-`-`=0```````L@`````````9
M`0``$0`8`("D8```````!`````````!L````$0`8`("I8```````"```````
M``"Y`P``$@`-`(`^0```````(@````````#R`@``$0`8`""E8```````"```
M``````"7`P``$@`-`*`X0```````R0````````#[````$0`8`."D8```````
M`0`````````>!```$@`-`,`\0```````O@$```````#8`@``$0`8`*"D8```
M````0```````````;&EB=&AR+G-O+C,`7TIV7U)E9VES=&5R0VQA<W-E<P!P
M=&AR96%D7V%T9F]R:P!C;&]S90!R96%D`'!T:')E861?9V5T<W!E8VEF:6,`
M;W!E;@!?7V5R<F]R`&QI8G!E<FPN<V\N-2XR,`!E;G9I<F]N`%!E<FQ?<WES
M7W1E<FT`4&5R;%]S>7-?:6YI=#,`4&5R;%]A=&9O<FM?;&]C:P!P97)L7V-O
M;G-T<G5C=`!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L7V%V7W-H:69T`%!E
M<FQ?<W9?,G!V7V9L86=S`%!E<FQ?<W9?<V5T<'9N`%]F:6YI`%!,7V1O7W5N
M9'5M<`!097)L7VYE=UA37V9L86=S`%!,7W1H<E]K97D`<&5R;%]F<F5E`%!E
M<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7W-V7W-E='!V`%!E
M<FQ?9W9?9F5T8VAP=@!P97)L7W)U;@!097)L7VYE=UA3`'!E<FQ?9&5S=')U
M8W0`4&5R;%]A=E]F971C:`!B;V]T7T1Y;F%,;V%D97(`<&5R;%]P87)S90!0
M97)L7W-A9F5S>7-M86QL;V,`<&5R;%]A;&QO8P!03%]M96UO<GE?=W)A<`!L
M:6)M+G-O+C4`;&EB8W)Y<'0N<V\N-0!L:6)U=&EL+G-O+CD`;&EB8RYS;RXW
M`%]?<')O9VYA;64`;65M8VAR`&QS=&%T`&UE;6-P>0!S=')S='(`;'-E96L`
M<W1R;&5N`')E861L:6YK`'-T<F1U<`!?:6YI=%]T;',`9V5T=6ED`')E86QL
M;V,`9G!R:6YT9@!M96UM;W9E`&UK9&ER`&UE;7-E=`!C;&]S961I<@!S=')N
M8VUP`'-T<FYC<'D`<W1R8VUP`&]P96YD:7(`<FUD:7(`9V5T<&ED`'-T<G1O
M:P!?7W-T86-K7V-H:U]F86EL`%]?<W1A8VM?8VAK7V=U87)D`'-P<FEN=&8`
M7U]S=&1E<G)P`&%C8V5S<P!A=&5X:70`<F5A9&1I<@!U;FQI;FL`7V5D871A
M`%]?8G-S7W-T87)T`%]E;F0`+W5S<B]L;V-A;"]L:6(O<&5R;#4O-2XR,"]M
M86-H+T-/4D4`<&%R7V-U<G)E;G1?97AE8P!P87)?8F%S96YA;64`6%-?26YT
M97)N86QS7U!!4E]"3T]4`'!A<E]E;G9?8VQE86X`<&%R7V-U<G)E;G1?97AE
M8U]P<F]C`'!A<E]D:7)N86UE`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED
M`'!A<E]C;&5A;G5P`'AS7VEN:70`<&%R7VUK=&UP9&ER`'!A<E]S971U<%]L
M:6)P871H`'!A<E]F:6YD<')O9P!M>5]P87)?<&P`<&%R7VEN:71?96YV`&UA
M:6X`1D)31%\Q+C```````@````(````"``,```````````````(``@`"``(`
M`@````(``@`"``(``P````(``@`#```````"``(``@`"``(``@```````P``
M``,``@`"``(````"``,``@`"`````@`"``(````"``(```````(``@`"````
M`0````$``0`!``$``0`!``$``0`!``$``0`!``$````!`````0`!``$````!
M`````0`!``(``0````$``@`````````!``$``0```!`````@````L"AZ!P``
M`P`P!`````````$``0`(`@``$`````````"P*'H'```"`#`$````````@*1@
M```````%````5```````````````H*1@```````%````6P``````````````
MX*1@```````%````60``````````````\*1@```````%````3```````````
M````(*5@```````%````5P``````````````4*)@```````'`````0``````
M````````6*)@```````'`````@``````````````8*)@```````'`````P``
M````````````:*)@```````'````!```````````````<*)@```````'````
M!0``````````````>*)@```````'````!@``````````````@*)@```````'
M````4@``````````````B*)@```````'````"```````````````D*)@````
M```'````"0``````````````F*)@```````'````"@``````````````H*)@
M```````'````"P``````````````J*)@```````'````#```````````````
ML*)@```````'````#0``````````````N*)@```````'````#@``````````
M````P*)@```````'````#P``````````````R*)@```````'````$```````
M````````T*)@```````'````$0``````````````V*)@```````'````$@``
M````````````X*)@```````'````$P``````````````Z*)@```````'````
M%```````````````\*)@```````'````%0``````````````^*)@```````'
M````%@```````````````*-@```````'````%P``````````````"*-@````
M```'````&```````````````$*-@```````'````&0``````````````&*-@
M```````'````/@``````````````(*-@```````'````3@``````````````
M**-@```````'````&@``````````````,*-@```````'````&P``````````
M````.*-@```````'````'```````````````0*-@```````'````'0``````
M````````2*-@```````'````'@``````````````4*-@```````'````'P``
M````````````6*-@```````'````(```````````````8*-@```````'````
M(0``````````````:*-@```````'````(@``````````````<*-@```````'
M````(P``````````````>*-@```````'````)```````````````@*-@````
M```'````)0``````````````B*-@```````'````)@``````````````D*-@
M```````'````)P``````````````F*-@```````'````*```````````````
MH*-@```````'````*0``````````````J*-@```````'````*@``````````
M````L*-@```````'````*P``````````````N*-@```````'````+```````
M````````P*-@```````'````+0``````````````R*-@```````'````+@``
M````````````T*-@```````'````+P``````````````V*-@```````'````
M,```````````````X*-@```````'````,0``````````````Z*-@```````'
M````,@``````````````\*-@```````'````,P``````````````^*-@````
M```'````-````````````````*1@```````'````-0``````````````"*1@
M```````'````-@``````````````$*1@```````'````-P``````````````
M&*1@```````'````.```````````````(*1@```````'````.0``````````
M````**1@```````'````.@``````````````,*1@```````'````.P``````
M````````.*1@```````'````/```````````````2(/L".C_!```Z*HX``!(
M@\0(PP#_-5Z((`#_)6"((``/'T``_R5>B"``:`````#IX/____\E5H@@`&@!
M````Z=#_____)4Z((`!H`@```.G`_____R5&B"``:`,```#IL/____\E/H@@
M`&@$````Z:#_____)3:((`!H!0```.F0_____R4NB"``:`8```#I@/____\E
M)H@@`&@'````Z7#_____)1Z((`!H"````.E@_____R46B"``:`D```#I4/__
M__\E#H@@`&@*````Z4#_____)0:((`!H"P```.DP_____R7^AR``:`P```#I
M(/____\E]H<@`&@-````Z1#_____)>Z'(`!H#@```.D`_____R7FAR``:`\`
M``#I\/[___\EWH<@`&@0````Z>#^____)=:'(`!H$0```.G0_O___R7.AR``
M:!(```#IP/[___\EQH<@`&@3````Z;#^____);Z'(`!H%````.F@_O___R6V
MAR``:!4```#ID/[___\EKH<@`&@6````Z8#^____)::'(`!H%P```.EP_O__
M_R6>AR``:!@```#I8/[___\EEH<@`&@9````Z5#^____)8Z'(`!H&@```.E`
M_O___R6&AR``:!L```#I,/[___\E?H<@`&@<````Z2#^____)7:'(`!H'0``
M`.D0_O___R5NAR``:!X```#I`/[___\E9H<@`&@?````Z?#]____)5Z'(`!H
M(````.G@_?___R56AR``:"$```#IT/W___\E3H<@`&@B````Z<#]____)4:'
M(`!H(P```.FP_?___R4^AR``:"0```#IH/W___\E-H<@`&@E````Z9#]____
M)2Z'(`!H)@```.F`_?___R4FAR``:"<```#I</W___\E'H<@`&@H````Z6#]
M____)1:'(`!H*0```.E0_?___R4.AR``:"H```#I0/W___\E!H<@`&@K````
MZ3#]____)?Z&(`!H+````.D@_?___R7VAB``:"T```#I$/W___\E[H8@`&@N
M````Z0#]____)>:&(`!H+P```.GP_/___R7>AB``:#````#IX/S___\EUH8@
M`&@Q````Z=#\____)<Z&(`!H,@```.G`_/___R7&AB``:#,```#IL/S___\E
MOH8@`&@T````Z:#\____);:&(`!H-0```.F0_/___R6NAB``:#8```#I@/S_
M__\EIH8@`&@W````Z7#\____)9Z&(`!H.````.E@_/___R66AB``:#D```#I
M4/S___\ECH8@`&@Z````Z4#\____)8:&(`!H.P```.DP_/___R5^AB``:#P`
M``#I(/S___\E=H8@`&@]````Z1#\__\`````54B)Y4%53(UO"$%44TB#[`B+
M'TB#/96+(```2&/#3(UDQQ!(BP6&BR``20]$Q(7;2(D%>8L@`'XZ2(M7"$B%
MTG0Q2(D5)X8@``^V`H3`="-(@\(!/"](BP43AB``2`]$PDB)!0B&(``/M@)(
M@\(!A,!UX;@HH&``2(7`="M(B??H1_S__[^T4D``Z#W\___H9/O__XG?3(GB
M3(GNZ)\A``")Q^C4_O__Z'_\__\/'P#KTY"0D)"0D)"0D)"0D)"0@#V1AB``
M`%5(B>5T$.LDD$B#P`A(B06EA2``_])(BP6<A2``2(L02(72=>3&!66&(``!
MR<,/'T0``&8/'T0``%5(@SU'@2```$B)Y706N`````!(A<!T#+\@H&``28G#
MR4'_X\G#D)"0D)"0D)"0D`^V#TB)^(3)="A(BP7'-0``2(U7`0^V,$B)^`\?
M1```0#CQ#[8*2`]$PDB#P@&$R77N\\-F#Q]$``!F#Q]$``!!5DB-=SA!54%4
M54B)_5-(@>P(`@``3(U,)(A-C8&`````3(G/2(L.2(/&"$B)RDB)R$C!X@A(
MP>`8)0```/^!X@``_P!("<)(B<A(P>@()0#_``!("<)(B<A(P>@8)?\```!(
M"<)(B<A(P>DH2,'H($B)%TC!X`A(B<)(P>`0)0```/^!X@``_P!("<)(B<A(
MP>D0)0#_``!("<)("<I(B5<(2(/'$$PYQP^%=?___TF-26A)C;%H`@``#Q]$
M``!(BP%(,T'82#-!J$@S09A(B<)(`<!(P>H?2`G"@^+_2(E1&$B#P0A(.?%U
MU$R+=0!(BWPDB$&]W+P;CT@#?2!(BTT(3(M5$$B+=1A,B?!,B?)-B?%(P>(%
M2,'H&TF)R$@)T$R)TDG!Z`*#X/]((<I)P>D"2(V\!YEY@EI(B<A(P>$>2/?0
M20G(2"'P08/@_T@#="202`G03(G"`<=,B?!,(?)(]]!(B?E,(=!(P>D;3`-4
M))A("<)(B?A(P>`%2(VT%IEY@EI(B?I("<%,B?!(P>`>`?%)"<%(B?A(B<Y!
M@^'_2/?02,'N&TPARDPAP$@)T$B)RDV-E`*9>8):2(G(2,'@!4@)QDB)R$0!
MUDF)^DCWT$G!Z@)(P><>3`-$)*!)"?I,(<A(B?=!@^+_2,'O&TP#3"2H3"'2
M2`G02(GR38V$`)EY@EI(B?!(P>`%2`G'2(GP1`''28G(2,'A'DG!Z`)(]]!)
M"<A,(=!(B?E!@^#_2,'I&TP#5"2P3"'"2`G02(GZ38V,`9EY@EI(B?A(P>`%
M2`G!2(GX1`')28GQ2,'F'DG!Z0)(]]!)"?%,(<!(B<Y!@^'_2,'N&TPARD@)
MT$B)RDV-E`*9>8):2(G(2,'@!4P#1"2X2`G&2(G(1`'628GZ2,'G'DG!Z@)(
M]]!)"?I,(<A(B?=!@^+_2,'O&TP#3"3`3"'22`G02(GR38V$`)EY@EI(B?!(
MP>`%2`G'2(GP1`''28G(2,'A'DG!Z`)(]]!)"<A,(=!(B?E!@^#_2,'I&TP#
M5"3(3"'"2`G02(GZ38V,`9EY@EI(B?A(P>`%2`G!2(GX1`')28GQ2,'F'DG!
MZ0)(]]!)"?%,(<!(B<Y!@^'_3"'*2,'N&TP#1"302`G02(G*38V4`IEY@EI(
MB<A(P>`%2`G&2(G(1`'628GZ2,'G'DG!Z@)(]]!)"?I,(<A(B?=!@^+_2,'O
M&TP#3"383"'22`G02(GR38V$`)EY@EI(B?!(P>`%2`G'2(GP1`''28G(2,'A
M'DG!Z`)(]]!)"<A,(=!(B?E!@^#_2,'I&TPAPD@)T$B)^DV-C`&9>8):2(GX
M2,'@!4@)P4B)^$0!R4F)\4C!YAY)P>D"2/?020GQ2(G.08/A_TP#5"3@3"'`
M3"'*2,'N&TP#1"3H2`G02(G*38V4`IEY@EI(B<A(P>`%2`G&2(G(1`'628GZ
M2,'G'DG!Z@)(]]!)"?I,(<A(B?=!@^+_2,'O&TP#3"3P3"'22`G02(GR38V$
M`)EY@EI(B?!(P>`%2`G'2(GP1`''28G(2,'A'DG!Z`)(]]!)"<A,(=!(B?E!
M@^#_2,'I&TPAPD@)T$B)^DV-C`&9>8):2(GX2,'@!4@)P4B)^$0!R4F)\4CW
MT$G!Z0)(P>8>3`-4)/A)"?%,(<!(B<Y!@^'_2,'N&TP#!"1,(<I("=!(B<I-
MC90"F7F"6DB)R$C!X`5("<9(B<A$`=9)B?I(P><>2<'J`DCWT$F)\TD)^DPA
MR$B)]T&#XO](P>\;3`-,)`A,(=)("=!(B?)-C80`F7F"6DB)\$C!X`5("<=(
MB?!$`<=)B<A(P>$>2<'H`DCWT$D)R$PAT$B)^4&#X/](P>D;3"'"2`G02(GZ
M38V,`9EY@EI(B?A(P>`%2,'F'DG!ZP),`U0D$$@)P4D)\TB)^$&#X_]$`<E(
M]]!,(=I(B<Y,(<!)B?E(P>X;2`G02,'G'DG!Z0)-C90"F7F"6DB)R$P#1"08
M2,'@!4D)^4B)RD@)QDB)R$&#X?](]]!,(<I$`=9,(=A(B?=)B<I("=!(P>$>
M2,'O&TV-A`"9>8):2(GP2<'J`DC!X`5,`UPD($D)RD@)QTB)\$&#XO](B?)(
M]]!$`<=,(<A)B?!,(=)("=!(P>8>2<'H`DV-G`.9>8):20GP2(GZ2(GX08/@
M_TP#3"0H2,'@!4C!ZAM("<),B<!,,=!$`=I,`U0D,$@Q^$B)T4V-C`&AZ]EN
M2(G02,'I&TC!X`5("<%$`<E)B?E(P><>2<'I`DB)SDD)^4B)UTC![AM!@^'_
M2,'O`DR)R$PQP$P#1"0X2#'02,'B'DV-E`*AZ]EN2`G72(G(@^?_2,'@!4@)
MQDB)^$0!UDPQR$P#3"1`2#'(2(GR38V$`*'KV6Y(B?!(P>H;2,'@!4@)PD0!
MPDF)R$C!X1Y)P>@"20G(2(G108/@_TC!Z1M,B<!(,?A(`WPD2$@Q\$V-C`&A
MZ]EN2(G02,'@!4@)P40!R4F)\4C!YAY)P>D"20GQ2(G.08/A_TC![AM,B<A,
M,<!,`T0D4$@QT$B-O`>AZ]EN2(G(2,'@!4@)Q@'^2(G72,'B'DC![P)("==(
MB?*#Y_](B?A,,<A(P>H;3`-,)%A(,<A-C80`H>O9;DB)\$C!X`5("<)$`<))
MB<A(P>$>2<'H`DD)R$B)T4&#X/](P>D;3(G`2#'X2`-\)&!(,?!-C8P!H>O9
M;DB)T$C!X`5("<%$`<E)B?%(P>8>2<'I`DD)\4B)SD&#X?](P>X;3(G(3#'`
M3`-$)&A(,=!(C;P'H>O9;DB)R$C!X`5("<8!_DB)UTC!XAY(P>\"2`G72(GR
M@^?_2(GX3#'(2,'J&TP#3"1P2#'(38V$`*'KV6Y(B?!(P>`%2`G"1`'"28G(
M2,'A'DG!Z`))"<A(B=%!@^#_2,'I&TR)P$@Q^$@#?"1X2#'P38V,`:'KV6Y(
MB=!(P>`%2`G!1`')28GQ2,'F'DG!Z0))"?%(B<Y!@^'_2,'N&TR)R$PQP$P#
MA"2`````2#'02(V\!Z'KV6Y(B<A(P>`%2`G&`?Y(B==(P>(>2,'O`D@)UTB)
M\H/G_TB)^$PQR$C!ZAM,`XPDB````$@QR$V-A`"AZ]EN2(GP2,'@!4@)PD0!
MPDF)R$C!X1Y)P>@"20G(2(G108/@_TC!Z1M,B<!(,?A(`[PDD````$@Q\$V-
MC`&AZ]EN2(G02,'@!4@)P40!R4F)\4C!YAY)P>D"20GQ2(G.08/A_TC![AM,
MB<A,,<!,`X0DF````$@QT$B-O`>AZ]EN2(G(2,'@!4@)Q@'^2(G72,'B'DC!
M[P)("==(B?*#Y_](B?A,,<A(P>H;3`.,)*````!(,<A-C80`H>O9;DB)\$C!
MX`5("<)$`<))B<A(P>$>2<'H`DF)TDD)R$B)T4G!Z@)!@^#_2,'I&TR)P$@Q
M^$@#O"2H````2#'P38V,`:'KV6Y(B=!(P>`%2`G!1`')28GQ2,'F'DG!Z0))
MB<Q)"?%(B<Y!@^'_2,'N&TR)R$PQP$P#A"2P````2#'02,'B'DB-O`>AZ]EN
M20G22(G(08/B_TC!X`5("<9,B=`!_DPQR$G![`)(,<A(P>$>2(GR38V$`*'K
MV6Y)"<Q(B?!!@^3_3`.,)+@```!(P>`%2,'J&TB)\TB+C"3(````2`G"3(G@
M2,'K`DPQT$0!PDP#E"3`````2#'P2,'F'DB)UTV-C`&AZ]EN2`GS2(G0@^/_
M2,'@!4C![QM("<=(B=A)B=-,,>!$`<])P>L"2#'02,'B'DF)^$V-E`*AZ]EN
M20G32(GX08/C_TC!X`5)P>@;20G`3`'I3(G810'03(G:3`'A2`G82"':3(G&
M2"'X28GY2,'N&T@)T$C!YQY)P>D"2`'!3(G`20GY2,'@!4&#X?]-B<)("<9,
MB<A,B<H!SDB+C"30````3`G83"':3"'`2(GW2`G02,'O&TG!X!Y,`>E)P>H"
M0;S6P6+*2`'930G"2`'!2(GP08/B_TC!X`5,B=)("<=,B=`!STB+C"38````
M3`G(2"'P28GX3`'I3`'93"'*28GS2`G02,'F'DG!Z!M(`<%(B?A)P>L"2,'@
M!4D)\TD)P$&#X_]!`<A(BXPDX````$R)V$P)T$R)VDR)QDPATD@A^$C![AM,
M`>E("=!,`<E)B?E(P><>2`'!3(G`2<'I`DC!X`5)"?E("<9!@^'_`<Y(BXPD
MZ````$R)R$P)V$R)RDB)]TPAVDPAP$P!Z4@)T$P!T4V)PD@!P4B)\$C![QM(
MP>`%2<'@'DG!Z@)("<=-"<(!ST&#XO](BXPD\````$R)T$R)TDF)^$P)R$PA
MRDG!Z!M,`>E((?!("=!,`=E)B?-(`<%(B?A(P>8>2,'@!4G!ZP))"<!)"?-!
M`<A!@^/_2(N,)/@```!,B=A,B=I,B<9,"=!,(=)(P>X;3`'I2"'X2`G03`')
M28GY2`'!3(G`2,'@!4@)Q@'.2,'G'DG!Z0))"?E(BXPD``$``$B)]T&#X?](
MP>\;3(G(3(G*3`G83"':3`'I3"'`3`'138G"2`G02<'@'DG!Z@)(`<%(B?!-
M"<)(P>`%08/B_T@)QTR)T$R)T@'/2(N,)`@!``!,"<A,(<I((?!)B?A("=!)
MP>@;3`'I3`'928GS2,'F'D@!P4B)^$G!ZP)(P>`%20G`00'(20GS2(N,)!`!
M``!!@^/_3(G&3(G83(G:2,'N&TP)T$PATDP!Z4@A^$P!R4F)^4@)T$C!YQY)
MP>D"2`'!3(G`20GY2,'@!4&#X?]("<9,B<A,B<H!SDB+C"08`0``3`G83"':
M3"'`2(GW2`G02,'O&TP!Z4P!T4V)PDG!X!Y(`<%(B?!)P>H"2,'@!4T)PD@)
MQT&#XO\!STB+C"0@`0``3(G03(G228GX3`'I3`'93`G(3"'*2"'P28GS2<'H
M&T@)T$C!YAY)P>L"2`'!2(GX20GS2,'@!4&#X_])"<!,B=A,B=I!`<A(BXPD
M*`$``$P)T$PATD@A^$R)QD@)T$C![AM,`>E,`<E)B?E(P><>2`'!3(G`2<'I
M`DC!X`5)"?E("<9!@^'_`<Y(BXPD,`$``$R)R$P)V$R)RDB)]TPAP$P!Z4P!
MT4PAVDV)PD@)T$G!X!Y(P>\;2`'!2(GP2<'J`DC!X`5-"<)("<=!@^+_`<](
MBXPD.`$``$R)T$P)R$R)TDF)^$PARD@A\$G!Z!M,`>E("=!,`=E)B?-(P>8>
M2`'!2(GX2<'K`DC!X`5)"?-)"<!!@^/_00'(2(N,)$`!``!,B=A,"=!,B=I,
MB<9,(=)((?A,`>E("=!,`<E)B?E(`<%,B<!(P>X;2,'@!4C!YQY)P>D"2`G&
M20GY`<Y!@^'_2(N,)$@!``!,B<A,B<I(B?=,"=A,(=I(P>\;3`'I3"'`2`G0
M3`'138G"2`'!2(GP2<'@'DC!X`5)P>H"2`G'30G"`<]!@^+_2(N,)%`!``!,
MB=!,B=))B?A,"<A,(<I)P>@;3`'I2"'P2`G03`'928GS2`'!2(GX2,'@!4D)
MP$$!R$C!YAY)P>L"20GS2(N,)%@!``!,B<9!@^/_2,'N&TR)V$R)VDP!Z4P)
MT$PATDP!R4@A^$F)^4@)T$C!YQY)P>D"2`'!20GY3(G`08/A_TP#K"1@`0``
M2,'@!4@)QDR)R$R)RDP)V$PAV@'.3"'`2(GW2`G030'52,'O&TD!Q4B)\$V)
MPDC!X`5)P>`>2<'J`D@)QTB+E"1H`0``1`'O30G"28GP08/B_TB)^4G!Z`),
MB=!,`>)(P>D;3#'(3`':2#'P2,'F'D@!PDB)^$D)\$C!X`5!@^#_2`G!3(G`
M`=%(BY0D<`$``$PQT$@Q^$B)SDC![AM,`>),`<I)B?E(P><>2`'"2(G(2<'I
M`DC!X`5)"?E("<9!@^'_`=9(BY0D>`$``$R)R$PQP$B)]T@QR$P!XDP!TDF)
MRD@!PDB)\$C![QM(P>`%2,'A'DG!Z@)("<=)"<H!UTB+E"2``0``08/B_TR)
MT$B)^4PQR$C!Z1M,`>)(,?!,`<))B?!(P>8>2`'"2(GX2<'H`DC!X`5)"?!(
M"<%!@^#_`=%(BY0DB`$``$R)P$PQT$B)SD@Q^$C![AM,`>),`<I)B?E(P><>
M2`'"2(G(2<'I`DC!X`5)"?E("<8!UDB+E"20`0``08/A_TR)R$B)]TPQP$C!
M[QM,`>)(,<A,`=))B<I(P>$>2`'"2(GP2<'J`DC!X`5)"<I("<=!@^+_`==(
MBY0DF`$``$R)T$PQR$B)^4@Q\$C!Z1M,`>),`<))B?!(P>8>2`'"2(GX2<'H
M`DC!X`5)"?!("<%!@^#_`=%(BY0DH`$``$R)P$PQT$B)SD@Q^$C![AM,`>),
M`<I)B?E(`<)(B<A(P>`%2,'G'DG!Z0)("<9)"?D!UDB+E"2H`0``08/A_TR)
MR$B)]TPQP$C![QM,`>)(,<A,`=))B<I(P>$>2`'"2(GP2<'J`DC!X`5)"<I(
M"<=!@^+_`==(BY0DL`$``$R)T$PQR$B)^4@Q\$C!Z1M,`>),`<))B?!(P>8>
M2`'"2(GX2<'H`DC!X`5)"?!("<%!@^#_`=%(BY0DN`$``$R)P$B)SDP!XDPQ
MT$C![AM(,?A,`<I)B?E(`<)(B<A(P><>2,'@!4G!Z0)("<9)"?D!UDB+E"3`
M`0``08/A_TR)R$B)]TPQP$C![QM,`>)(,<A,`=))B<I(P>$>2`'"2(GP2<'J
M`DC!X`5)"<I("<=!@^+_`==(BY0DR`$``$R)T$PQR$B)^4@Q\$C!Z1M,`>),
M`<))B?!(`<)(B?A(P>`%2`G!2,'F'DG!Z`(!T4D)\$B+E"30`0``08/@_TB)
MSDR)P$C![AM,`>),,=!(,?A,`<I)B?E(`<)(B<A(P><>2,'@!4G!Z0)("<9)
M"?D!UDB+E"38`0``08/A_TR)R$B)]TF)\TPQP$C![QM,`>)(,<A,`=))B<I(
MP>$>2`'"2(GP2<'J`DC!X`5)"<I("<=!@^+_`==(BY0DX`$``$R)T$B)^4B)
M^TP!XDP!PDPQR$C!Z1M(,?!)P>L"2,'F'D@!PDB)^$D)\TC!X`5!@^/_2,'K
M`D@)P4R)V`'12(N4).@!``!,,=!(,?A)B<A(P><>2<'H&T@)^TP!XH/C_TP!
MRDF)R4@!PDB)R$C!X`5)"<!(B=A!`=!(BY0D\`$``$PQV$@QR$R)QTR)QDC!
M[QM,`>),`=)(`<),B<!(P>`%2`G'`==(P>$>2<'I`DD)R4B+E"3X`0``2,'N
M`D&#X?](B?E,B<A(P>D;3`'B2#'83`.D)``"``!,,<!,`=I)P>`>2`'"3`G&
M2(GX2,'@!8/F_T@)P4B)\$D!W$PQR`'12#'X2(G*20'$2(G(2,'B!4C!Z!M(
M"=!$`>!$`?!(B44`2(GX2,'G'DC!Z`(#30A("?@#11`#=1A$`TT@2(E-"$B)
M11!(B7483(E-($B!Q`@"``!;74%<05U!7L-,B60DX$R)?"3X28G\2(E<)-!(
MB6PDV$F)]TR);"3H3(ET)/!(@^PX2(7_=24QP$B+7"0(2(ML)!!,BV0D&$R+
M;"0@3(MT)"A,BWPD,$B#Q#C#3(LU]W,@`$V%]G3/#[8'A,!U!#'`ZQ<\/4B)
M^G3U2(/"`0^V`H3`=46)T$0IX$F++DB%[72E3&/H3(GS9I!,B>I,B>9(B>_H
M3N;__X7`=0I)C40M`(`X/70:2(MK"$B#PPA(A>UUU^EO____9I`\/76LZ[5,
M*?-(@\`!2,'[`T&)'^E6____#Q^``````%532(G[2(/L&$B-;"049I`QP$B)
M[DB)W^@#____2(7`="9(8T0D%$B-%,4`````2`,5.G,@`$B#P@A(BP)(A<!(
MB4+X=?#KR$B#Q!A;7<.02(/L&#'`2(UT)!3HP/[__TB#Q!C##Q]$``!F#Q]$
M``!(@^P(@SW5;2``_W0+BP7-;2``2(/$",,QP+_(4D``Z+S___](A<!T!P^V
M`(3`=1,QP(D%J&T@`(L%HFT@`$B#Q`C#/#`/E<`/ML#KY0\?`$R)9"3H2(E<
M)-A)B?Q(B6PDX$R);"3P3(ET)/A(@>RH````2(7_=`6`/P!U,TB+G"2`````
M2(NL)(@```!,BZ0DD````$R+K"28````3(NT)*````!(@<2H````PP\?`.BG
MY?__2(7`2(G%=,`/'P!(B>_HA./__TB%P`^$H0```$B-6`B_TU)``+D"````
M_$B)WO.F=-F_TE)``+D#````2(G>\Z9TR$R)Y^CLX___2(G?28G%Z.'C__]!
MC40%`DAC^.A4XO__2(G92(G'28G%3(GBOM520``QP.A\X___2(GF3(GOZ"'C
M__^#P`%T$0^W1"0()0#P```]`$```'0V3(GOZ./B__],B>_H>^7__TB)[^CC
MXO__2(7`#X5?____2(GOZ*+E__],B>?H"N3__^GV_O__3(GOZ,'^__^0Z\</
M'X``````#Q^``````%-(B?N+/59L(`#H/>3__TB-L)@!``!(B=_HGN/__X7`
M=`1;,<##BSTT;"``Z!OD__\/MX"@`0``)0#P```]`$```'0>BST6;"``Z/WC
M__\/MX"@`0``)0#P```]`*```'7`2(G?O@(```#H[>/__UN%P`^4P`^VP,,/
M'X``````2(E<).A(B6PD\$R)9"3X2('L.`@``$B-G"00!```2(L%VVL@`$B)
MA"08"```,<#H2.3__[EU5$``B<*^VU)``#'`2(G?Z$+B__^%P'DV,>U(BY0D
M&`@``$@S%:%K(`!(B>AU8$B+G"0@"```2(NL)"@(``!,BZ0D,`@``$B!Q#@(
M``##2(G?N@`$``!(B>;H^.#__X7`B<-XM(UX`4AC_^BGX/__2(7`=*1(8]M(
MB<5(B>9(B=I(B<?HCN/__\8$*P#KC.@SX___#Q^``````.DK____#Q]$``!F
M#Q]$``!!5S'`059)B?Y!54%454B)]5-(@^P8@#X]#Y3`2`'%2(GOZ,7A__](
MC70D%$F)QTR)]S'`Z'?[__](A<!(B<-T-$B)Q^BCX?__23G'#X>_````#[9%
M`$B#Q0&(`TB#PP&$P'7N2(/$&#'`6UU!7$%=05Y!7\-(BSV$;R``13'DN!``
M``!(@S\`=")(B?H/'P!(BT((08/$`4B#P@A(A<!U[T&-1"0"2)A(P>`#BQ4.
M:R``A=(/A2,!``!(B<?'!?EJ(``!````Z*#?__](A<!)B<4/A"D!``!)8\1(
MBS4>;R``3(GO2(T<Q0````!(B=KH%^/__TR)+01O(`!(BP7];B``2,=$`P@`
M````1(ED)!1!#[863(GPA-(/A+8```"`^CT/A*T````/'X``````2(/``0^V
M$(32#X6)````1"GP2)A(8UPD%$J-?#@"2,'C`T@#':=N(`#H#M___TB%P$B)
M`P^$EP```$AC5"042(L%BFX@`$B+%-!!#[8&A,"(`G0B/#UT'DR)]^L+#Q\`
M2(/'`3P]=`X/MD<!2(/"`83`B`)UZL8"/0\?@``````/MD4`2(/%`8A"`4B#
MP@&$P'7MZ9S^__^`^CT/A5_____I:?___S'`Z6?___](B<;H5^'__TB%P$B)
M!1%N(`!T$$ECQ$B-',4`````Z?O^__](@\08N/____];74%<05U!7D%?PP\?
M1```9@\?1```05=!5DF)_D%5051!O/%20`!54TB#[$A,BSTB&0``28GE2,<$
M)/%20`!(QT0D".=20`!(QT0D$/120`!(QT0D&.I20`!(QT0D(.]20`!(QT0D
M*`%30`!(QT0D,`````#K'DR)]DR)YS'`Z'+]__]-BV4(28/%"$V%Y`^$B0``
M`#'`3(GGZ#?Z__](A<!(B<5TT(`X`'3+3(GV2(G'Z,O@__](A<!UR$R)]^@>
MW___3(G_2(G#Z!/?__](C5P#`4B)[^@&W___2(T\`^A]W?__28GH2(G'2(G#
M3(GY3(GROAQ40``QP.BBWO__3(GG,<!(B=[HZ?S__TV+90A)@\4(387D#X5W
M____2(/$2%M=05Q!74%>05_#9@\?A```````2(/L.+\,4T``2(L%T&<@`$B)
M1"0H,<!(BP72%P``2(D$)$B+!<\7``!(B40D"$B+!<L7``!(B40D$$B+!<<7
M``!(B40D&`^W!<,7``!FB40D(#'`Z/?X__\QP+\54T``Z.OX__\QP+\=4T``
MZ-_X__\QP+\F4T``Z-/X__\QP+\M4T``Z,?X__\QP+\]4T``Z+OX__\QP+])
M4T``Z*_X__\QP+_(4D``Z*/X__\QP+]24T``Z)?X__\QP+]<4T``Z(OX__\Q
MP+]F4T``Z'_X__\QP+]S4T``Z'/X__\QP+]\4T``Z&?X__\QP+^'4T``Z*OX
M__](A<!T#TB)QK]24T``,<#HM_O__S'`OYA30`#HB_C__TB%P'0/2(G&OZI3
M0``QP.B7^___,<"_M5-``.AK^/__2(7`=#9(B<:_25-``#'`Z'?[__\QP+[A
M4T``ORU30`#H9OO__TB+1"0H2#,%>F8@`'512(/$.,,/'P`QP+_%4T``Z"3X
M__](A<!T$4B)QK_(4D``,<#H,/O__^NW2(UT)!&_UE-``+D*````_/.F=:-(
MC70D&[_(4D``,<#H"?O__^N0Z![>__]FD$B#[`CH8]W__XG'Z'S;__\QTDB%
MP'0#2(L02(G02(/$",,/'X``````#Q^``````%532(G[2(/L"$B%_W0(#[8O
M0(3M=1!(@\0(O]-20`!;7>DVW/__Z)'<__](`=A(C5#_2#G3#X.>````2(L]
MYA4```^V0/\/MC=`./!T">LJ#[8*.,%U9DB#Z@%(.=-FD'+N2#G:=2E`.B]T
MJDB#Q`A;7>GEV___#[8"0#C&=.-(@^H!2#G3<N_KV&8/'T0``$B#Z@%(.=-S
M"0^V`CH'9I!T[D@IVC')2(U"`D@]``0``'8.2(/$"$B)R%M=PXG(Z[E(@\(!
M2(G>OV"E8`#H"MW__[E@I6``Z]I(BSU(%0``ZX`/'X``````#Q^``````$B)
M7"3P2(EL)/A(@^P82(G[Z/K^__](B<?H0M___TB)Q3'`Z+CV__^%P'0*2(7;
M=`6`.P!U#TB+7"0(2(ML)!!(@\08P[[C4T``2(GOZ!K=__](.<5UWTB)WTB+
M;"002(M<)`A(@\08Z</V__\/'P!32(/L((E\)!Q(B70D$$B-?"0<2(E4)`A(
MC70D$$B-5"0(Z$7=__^Z3!I``+^,&T``2(G6Z`/<__^`/9!D(```=2_HE=K_
M_TB%P$B)QTB)!?QH(``/A)@!``#H3=O__XL]"V0@`.CRV___QH"=!P```(L]
M^6,@`.C@V___@(BZ`P```HL]YV,@`.C.V___@(BZ`P```8M$)!R#P`5(8\A(
MA<D/B!P!``#R2`\JP?(/6`6[4@``9@\N!;M2```/AQX!``!(C3S-`````.A<
MW/__2(MT)!!(B<%(B06):"``3(U)^$B+!DC'00CH4T``2(D!2(L%4&,@`$C'
M01CK4T``2(E!$$2+1"0<QP5-:"``!````$&#^`%^(TR-2?B_`0```+H(````
M2(L$%H/'`4B)1`H82(/""$$Y^'_K08U`!+XP4D``13'`2)A)QP3!`````(M4
M)!Q(BSWS9R``@\(#Z*?8__^%P(G#=$E(BSW>9R``Z-7:__\QP+\]4T``Z,WT
M__](A<!T&4B+/<%G(`#H6-C__^BCV?__B=A(@\0@6\-(BSVP9R``2(7_=$WH
MWOW__^O42(L]E6<@`.B,V/__B</KITB)R$B)RDC1Z(/B`4@)T/)(#RK`\@]8
MP.G,_O__OO"D8`"_Y%)``#'`Z/K:__]`MP'H0MO__[])4T``Z$ST__](A<!(
MB<=(B05'9R``=9KI</___P\?A```````05=!5D%5051)B?R_25-``%532(GS
M2('L*`0``$B+!4UB(`!(B80D&`0``#'`Z/[S__](BRUO$@``3(GG28G%2(GN
MZ)7:__](A<!T.4R)YK]F4T``,<#H]?;__TB+E"08!```2#,5!F(@`$R)X`^%
M3@$``$B!Q"@$``!;74%<05U!7D%?PTR)Y^BOV/__3(L]'!(``$B)WT&)QDR)
M_NC:U___2(7`2(G#=*)!@\8!1(ET)`Q,C70D$(`[`+C34D``2`]$V$V%[703
M2(G>3(GOZ*C:__^%P`^$G````$B)W^A8V/__B<%(F`^V1`/_.D4`=2&-0?](
MF$B-%!@/'T0```^V0O_&`@"#Z0%(@^H!.D4`=.V+1"0,`<@]_P,```^/*/__
M_TV)X$B)Z4B)VKX<5$``3(GW,<#HP-?__XL]#F$@`.CUV/__2(VPF`$``$R)
M]^A6U___A<!U'HL]\&`@`.C7V/__#[>`H`$``"4`\```/0"```!T&S'_3(G^
MZ/K6__](A<!(B<,/A2K____IN?[__[X!````3(GWZ*S8__^%P'743(GVOV93
M0`#HG_7__TR)]^@CU___28G$Z9K^___HIMC__V8N#Q^$``````!!5TF)_[])
M4T``059!54%455-(@>QH@0``2(L%@&`@`$B)A"18@0``,<!(QT0D4.Y30`!(
MQT0D6/-30`!(QT0D8`````#H%O+__TB%P$B)PW0)@#@`#X6!`@``,<!(C6PD
M4.@9^O__2(7`2(G##X3(`0``2(G?Z/'6__](C7P``>AGU?__@#L`28G%=")(
MB<4/MA-(B>\QP+X#5$``2(/#`4B#Q0+H@M;__X`[`'7A2(UL)""_JE-``$C'
M1"0@JE-``$C'1"0HHU-``$C'1"0P"%1``$C'1"0XP%-``$C'1"1`$%1``$C'
M1"1(`````.L12(M]"$B#Q0A(A?\/A&4!```QP.A7\?__2(7`2(G#=."`.`!T
MVTB)Q^@"\___A<!TSTB)W^CBU?__2(7`28G$#X0T`0``3(GGZ"[6__],B>](
MB</H(];__XV$`P0$``!,8_!,B??HD=3__TB+%78/``!(B<=(B<5-B>E!N.-3
M0`"^&E1``#'`2(G12(E4)!!,B>+HI-7__[[``0``2(GOZ&?6__^#P`$/A%8!
M``"+/=Q>(`#HP];__TB-L)@!``!(B>_H)-;__X7`=2*+/;Y>(`#HI=;__P^W
M@*`!```E`/```#T`0```#X10`0``28L72(L].%\@`$B)Z;XX54``,<`QV^@C
MU?__2(N4)%B!``!(,Q687B``2(G8#X6)`@``2('$:($``%M=05Q!74%>05_#
M2(G'Z.'4__](B<-(@\4(2(7;#X4X_O__2(M]`$B%_P^$2`(``#'`Z!'P__](
MA<!TVH`X`'7*2(/%"$B%VW39Z0S^__]%,>2`/:,-````2,=$)'`45$``NQ14
M0`!(QT0D>--20`!(QX0D@`````````!(C6PD<'4HZ9;^__]-A>0/A8W^__](
MBUT(2(7;#X2`_O__2(/%"(`[``^$<_[__TB)W^A5\?__A<!TT4B)W^@UU/__
M28G$Z\1(B<?HO/3__TB)W^@@U/__2(G#Z07____HT]7__X,X$0\?0``/A)C^
M___HP=7__TF+%T2+`$B)Z4B+/05>(`"^^%1``#'`,=OH\]/__^G+_O__BSU,
M72``Z#/5__^+F*0!``#HJ-3__SG##X62_O__BSTN72``Z!75__\/MX"@`0``
M)?\!```]P`$```^%</[__TR)]^AVTO__O^I20`!(B<,QP.C;[O__2(7`2(G'
M#X2/`0``Z';3__])BS](B<;HC_K__TB%P$F)Q0^$<P$``$R)[^BWT___@_@#
M08G`#X_D````,<#HN.[__X7`=18Q]DR)[^AFTO__A<")1"0<#X5&`0``ON%3
M0`"_R%)``#'`Z(WQ___H)-7__TB+3"0008G`0;EA5$``2(GJOCQ40`!(B=\Q
MP$4QY.@1T___ZSCHJM3__X,X$75`Z/#4__](BTPD$$&#Q`%!B<!%B>%(B>J^
M2E1``$B)WS'`2,<$)&%40`#HU]+__[[``0``2(G?Z)K3__^#P`%TMDB)[^CM
MU/__2(G>OTE30``QP.@"\?__2(G?Z!KS___I;OW__P\?1```N_Q30`#IV?O_
M_V8/'T0``.CWT___2)B_(U1``$F-=`7\N`4```#\2(G!\Z8/A?_^__]!@_@$
M=!E!C4#\2(M4)!!(F$$/MD0%_SH"#X7@_O__38MG"$V%Y`^$T_[__TR)Y^AV
MTO__2(/X`P^&P?[__TF-=`3\ORA40`"Y!0```/SSIDT/1.SIIO[__P\?1```
M38LOZ87^__^Z`@```$C'QN[___^)Q^@ATO__BWPD'$B-M"20````N@8```#H
M2]+__X"\))``````=0Z`O"21````0P^$)P0``(M\)!PQ]C'23(VT))"```#H
MWM'__[^)J\WOOO[<NIBY\.'2PTC'A"20@````2-%9TB)O"28@```28/&.$B)
MM"2@@```2,>$)*B```!V5#(02(F,)+"```!(QX0DN(````````!(QX0DP(``
M``````#'A"0(@0```````(M\)!Q(C;0DD````+H`@```Z*+1__^%P$&)Q0^.
M.`$``$B+C"2X@```26/52(N$),"```!,C:0DD````(TTT4@YSDB)M"2X@```
M2(/0`$C!ZAU(B80DP(```$@!E"3`@```BY0D"($``(72=&7I@0```$F+!"1(
MC;PDD(```$&#[4!(B80DR(```$F+1"0(28E&"$F+1"0028E&$$F+1"0828E&
M&$F+1"0@28E&($F+1"0H28E&*$F+1"0P28E&,$F+1"0X28/$0$F)1CCHBM3_
M_T&#_3]_FDECU4R)YDR)]^@BTO__1(FL)`B!``#I#?___[A`````2&/Z2(VT
M))`````IT$F-/#Y!.<5!B<1%#T[E36/\3(GZZ.K1__]$B>`#A"0(@0``@_A`
MB80D"($```^%R/[__TB-C"20````12GE2(V\))"```!-C20/Z`C4___I>?__
M_XM\)!SH]L___TR+I"2X@```3(NL),"```!,B>!(P>@#@^`_2&/0@\`!@_@X
MQH04R(```(`/CJ8"``!(8_BZ0````#'V*<)(C;P\R(```$ACTNB9T?__2(V\
M))"```#HH-/__TB-O"20@```N0<````QP/Q(@\<X\TBK3(GH2(V\))"```!$
MB*PD`X$``$C!Z!A$B*0D!X$``$R-M"00@0``B(0D`($``$R)Z$R-O"1`@0``
M2,'H$(B$)`&!``!,B>A-B?5(P>@(B(0D`H$``$R)X$C!Z!B(A"0$@0``3(G@
M2,'H$(B$)`6!``!,B>!%,>1(P>@(B(0D!H$``.@"T___2(N4))"```!(B="(
ME"1#@0``2,'H&(B$)$"!``!(B=!(P>@0B(0D08$``$B)T$B+E"28@```2,'H
M"(B$)$*!``!(B="(E"1'@0``2,'H&(B$)$2!``!(B=!(P>@0B(0D18$``$B)
MT$B+E"2@@```2,'H"(B$)$:!``!(B="(E"1+@0``2,'H&(B$)$B!``!(B=!(
MP>@0B(0D28$``$B)T$B+E"2H@```2,'H"(B$)$J!``!(B="(E"1/@0``2,'H
M&(B$)$R!``!(B=!(P>@0B(0D38$``$B)T$B+E"2P@```2,'H"(B$)$Z!``!(
MB="(E"13@0``2,'H&(B$)%"!``!(B=!(P>@0B(0D48$``$B)T$C!Z`B(A"12
M@0``0P^V%#Q,B>\QP+X#5$``28/$`4F#Q0+HM<W__TF#_!1UWD&Y851``$V)
M\,:$)#B!````ZW&`O"22````00^%R_O__X"\)),```!##X6]^___@+PDE```
M`$@/A:_[__^`O"25````10^%H?O__XM\)!RZ`@```$C'QL;____H?\W__XM\
M)!Q(C;0DD````+HI````Z*G-__],C80DD````$&Y851``$B+3"002(GJOBU4
M0`!(B=\QP.@4S?__Z4KZ__^Z.````$AC^#'V*<)(C;P\R(```$ACTNCSSO__
MZ7G]__]FD$%7059!54%455-(@>P8!```BSTI5B``2(L%0E8@`$B)A"0(!```
M,<#H_\W__[\M4T``QH"I`````3'`Z.#G__](A<!T"8`X,0^$?@(``#'`Z"ON
M__^+/>55(`#HS,W__[D+````2(G'N@$```"^6U1``.C%R___2(7`#X3&````
M13'V@SVF6B```4B+0!!,BW@H#XZ<````0;T!````,>U!O`@```#K+TB+<Q!(
MBP6%6B``2HL\(.BPSO__A<!U=$&-10%(@\4!28/$"#D%7EH@`'Y=08G%BSUC
M52``08GNZ$?-__\QR4B)QTB)ZDR)_N@'S?__2(7`=#I(BQB+0PPE``0@`#T`
M!```=)R+/2Y5(`#H%<W__TB)WDB)Q[D"````,=+H4\[__TB)QNE[____18GN
MBQ7V62``C4+_1#GP#X12`0``BSWT5"``Z-O,__^Y`P```$B)Q[H!````OF!4
M0`#HU,K__TB%P$B)Q70S2(M`$(L]QE0@`$B+&.BJS/__NF)40`!(B<=(B=[H
MNLK__TB+11!(BQCV0PY`#X4"`@``BSV75"``Z'[,__^Y`P```$B)Q[H!````
MOH530`#H=\K__TB%P$B)PW0X,<"_9E-``.A'YO__2(7`2(G%#X0<`0``2(M#
M$(L]450@`$B+&.@US/__2(GJ2(G'2(G>Z$?*__^+/354(`#H',S__[])4T``
MQH"I`````#'`Z/WE__](A<!(B07[6"``#X2H````2(L][E@@`+[``0``Z'C+
M__^%P'4G2(N$)`@$``!(,P4)5"``#X5!`0``2('$&`0``%M=05Q!74%>05_#
M@_@1=-2#^/]TSXG!2(L%ME@@`$B+%9]8(`"_N%5``$B+,#'`Z"3,__^#Z@$/
MCJ7^__^[`0```(L]E%,@`(/#`>AXR___3(G^2(G'Z&W)__\Y'6M8(`!_W^EZ
M_O__@'@!``^$?_W__^ES_?__2(L]5E@@`.C9\O__2(7`2(D%-U@@``^%//__
M_[^054``Z+O+__](BP4P6"``BSTR4R``3(LH2(M#$$R+(.@/R___NO\#``!(
MB>:_9U1``.B]R/__A<")PGY&@^H!2&/:@#P<`'58A=)^-DB)VKXO````2(GG
MZ#?*__](A<!T(8L]X%(@`.C'RO__2(G92(G'2(GB3(GFZ';*___IBO[__XL]
MOU(@`.BFRO__3(GJ2(G'3(GFZ+C(___I;/[__TACV.NG9I#HM\K__XL]E5(@
M`.A\RO__2(G>2(G'Z+'*___IX_W__TB#[`B+/792(`#H7<K__[GH5$``2(G'
MNGP;0`"^>E1``$B#Q`CI0LO__V8/'T0``$B#[`B+/492(`#H+<K__TB)Q^BY
M____BSTS4B``Z!K*__]!N&%40`!(B<=%,<E,B<&Z0$Y``+Z65$``2(/$".DX
MR?__D)"0D)"0D)"0D)"054B)Y5-(@^P(2(L%<$T@`$B#^/]T%3';_]!(BX/X
MGV``2(/K"$B#^/]U[4B#Q`A;R<.0D$B#[`CHT\O__TB#Q`C#````````4$%2
M7T-,14%.`"XN`"5S+R5S`"]P<F]C+R5I+R5S`$Q)0E!!5$@`1%E,1%],24)2
M05)97U!!5$@`4TA,24)?4$%42`!015),-4Q)0@!015),3$E"`%!%4DPU3U!4
M`%!%4DQ)3P!005)?24Y)5$E!3$E:140`4$%27U-005=.140`4$%27U1%35``
M4$%27T1%0E5'`%!!4E]#04-(10!005)?4%)/1TY!344`4$%27T%21T,`4$%2
M7T%21U9?,`!005)?1TQ/0D%,7T1%0E5'`%!!4E]'3$]"04Q?5$U01$E2`%!!
M4E]435!$25(`4$%27T=,3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%04X`4$%2
M7T-,14%./0`Q`'!A<BT`+64`+2T`55-%4@!54T523D%-10!365-414T`)3`R
M>`!414U01$E2`%1-4``O=&UP+P`E<R5S)7,E<P!P87)L`"YP87(`)7,E<V-A
M8VAE+25S)7,`)7,E<W1E;7`M)74E<P`E<R5S=&5M<"TE=2TE=25S`$%21U8`
M&`!P97)L`"]P<F]C+V-U<G!R;V,O9FEL90!$>6YA3&]A9&5R.CIB;V]T7T1Y
M;F%,;V%D97(`26YT97)N86QS.CI005(Z.D)/3U0`.@````!?7T5.5E]005)?
M0TQ%04Y?7R`@("`@("`@("`@("`@(```````````&%1```````"K5$``````
M`'!E<FQX<VDN8P`````````E<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D
M:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*````````)7,Z('!R:79A
M=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V92!I
M="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@```````%5N86)L92!T;R!C
M<F5A=&4@8V%C:&4@9&ER96-T;W)Y```````````E<SH@8W)E871I;VX@;V8@
M<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE
M:2D*``````````!E=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P("1[
M,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL
M"G!A8VMA9V4@7U]P87)?<&P["FUY("@D<&%R7W1E;7`L("1P<F]G;F%M92P@
M0'1M<&9I;&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E<75I
M<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER
M92!&:6QE.CI3<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I
M<FYA;64H)'!A<E]T96UP*3L*;W5T<RAQ<7M296UO=FEN9R!F:6QE<R!I;B`B
M)'!A<E]T96UP(GTI.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M
M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A
M<E]T96UP.PII9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS,B<I
M('L*;7D@)'1M<"`](&YE=R!&:6QE.CI496UP*`I414U03$%412`]/B`G=&UP
M6%A86%@G+`I$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I
M<BDL"E-51D9)6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIP<FEN="`D
M=&UP("(C(2]B:6XO<V@*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*
M<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@
M=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR
M;2`G(B`N("1T;7`M/F9I;&5N86UE("X@(B<*(CL*8VAM;V0@,#<P,"PD=&UP
M+3YF:6QE;F%M93L*;7D@)&-M9"`]("1T;7`M/F9I;&5N86UE("X@)R`^+V1E
M=B]N=6QL(#(^)C$@)B<["F-L;W-E("1T;7`["G-Y<W1E;2@D8VUD*3L*;W5T
M<RAQ<2A3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L
M96%N=7`Z("D*+B`D=&UP+3YF:6QE;F%M92D["GT*?2!]"D)%1TE.('L*26YT
M97)N86QS.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!
M4CHZ0D]/5#L*979A;"!["E]P87)?:6YI=%]E;G8H*3L*:68@*&5X:7-T<R`D
M14Y6>U!!4E]!4D=67S!](&%N9"`D14Y6>U!!4E]!4D=67S!]("D@>PI`05)'
M5B`](&UA<"`D14Y6>R)005)?05)'5E\D7R)]+"`H,2`N+B`D14Y6>U!!4E]!
M4D=#?2`M(#$I.PHD,"`]("1%3E9[4$%27T%21U9?,'T["GT*96QS92!["F9O
M<B`H:V5Y<R`E14Y6*2!["F1E;&5T92`D14Y6>R1??2!I9B`O7E!!4E]!4D=6
M7R\["GT*?0IM>2`D<75I970@/2`A)$5.5GM005)?1$5"54=].PIM>2`E0V]N
M9FEG(#T@*`IP871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG
M(#H@)SHG*2P*7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3
M,GQC>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@*"1>
M3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G
M;F%M92@I.PI?<V5T7W!A<E]T96UP*"D["FUY("@D<W1A<G1?<&]S+"`D9&%T
M85]P;W,I.PI["FQO8V%L("1324=[7U]705).7U]](#T@<W5B('M].PIO<&5N
M(%]&2"P@)SPG+"`D<')O9VYA;64@;W(@;&%S=#L*8FEN;6]D92A?1D@I.PIM
M>2`D8G5F.PIM>2`D<VEZ92`]("US("1P<F]G;F%M93L*;7D@)&]F9G-E="`]
M(#4Q,CL*;7D@)&ED>"`]("TQ.PIW:&EL92`H,2D*>PHD;V9F<V5T(#T@)'-I
M>F4@:68@)&]F9G-E="`^("1S:7IE.PIS965K(%]&2"P@+21O9F9S970L(#(@
M;W(@9&EE('%Q6W-E96L@9F%I;&5D(&]N("(D<')O9VYA;64B.B`D(5T["FUY
M("1N<F5A9"`](')E860@7T9(+"`D8G5F+"`D;V9F<V5T.PID:64@<7%;<F5A
M9"!F86EL960@;VX@(B1P<F]G;F%M92(Z("0A72!U;FQE<W,@)&YR96%D(#T]
M("1O9F9S970["B1I9'@@/2!R:6YD97@H)&)U9BP@(EQN4$%2+G!M7&XB*3L*
M;&%S="!I9B`D:61X(#X](#`@?'P@)&]F9G-E="`]/2`D<VEZ92!\?"`D;V9F
M<V5T(#X@,3(X("H@,3`R-#L*)&]F9G-E="`J/2`R.PI]"FQA<W0@=6YL97-S
M("1I9'@@/CT@,#L*)&]F9G-E="`M/2`D:61X("T@-#L*<V5E:R!?1D@L("TD
M;V9F<V5T+"`R.PIR96%D(%]&2"P@)&)U9BP@-#L*<V5E:R!?1D@L("TD;V9F
M<V5T("T@=6YP86-K*").(BP@)&)U9BDL(#(["G)E860@7T9(+"`D8G5F+"`T
M.PHD9&%T85]P;W,@/2`H=&5L;"!?1D@I("T@-#L*;7D@)7)E<75I<F5?;&ES
M=#L*=VAI;&4@*"1B=68@97$@(D9)3$4B*2!["G)E860@7T9(+"`D8G5F+"`T
M.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FUY("1F=6QL
M;F%M92`]("1B=68["F]U=',H<7$H56YP86-K:6YG(&9I;&4@(B1F=6QL;F%M
M92(N+BXI*3L*;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=
M>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*;7D@*"1B87-E;F%M92P@)&5X="D@
M/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PIR96%D(%]&2"P@
M)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PII
M9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA
M;"DD+VDI('L*;7D@*"1O=70L("1F:6QE;F%M92D@/2!?=&5M<&9I;&4H)&5X
M="P@)&-R8RD["FEF("@D;W5T*2!["F)I;FUO9&4H)&]U="D["G!R:6YT("1O
M=70@)&)U9CL*8VQO<V4@)&]U=#L*8VAM;V0@,#<U-2P@)&9I;&5N86UE.PI]
M"B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M
M93L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA;65](#T@)&9U;&QN
M86UE.PI]"F5L<VEF("@@)&9U;&QN86UE(#U^(&U\7B\_<VAL:6(O?"!A;F0@
M9&5F:6YE9"`D14Y6>U!!4E]414U0?2`I('L*;7D@)&9I;&5N86UE(#T@(B1%
M3E9[4$%27U1%35!]+R1B87-E;F%M921E>'0B.PIO=71S*")32$Q)0CH@)&9I
M;&5N86UE7&XB*3L*;W!E;B!M>2`D;W5T+"`G/B<L("1F:6QE;F%M92!O<B!D
M:64@)"$["F)I;FUO9&4H)&]U="D["G!R:6YT("1O=70@)&)U9CL*8VQO<V4@
M)&]U=#L*?0IE;'-E('L*)')E<75I<F5?;&ES='LD9G5L;&YA;65](#T*)%!!
M4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]/B`D
M8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA;64L"GT["GT*<F5A
M9"!?1D@L("1B=68L(#0["GT*;&]C86P@0$E.0R`]("AS=6(@>PIM>2`H)'-E
M;&8L("1M;V1U;&4I(#T@0%\["G)E='5R;B!I9B!R968@)&UO9'5L92!O<B`A
M)&UO9'5L93L*;7D@)&9I;&5N86UE(#T@9&5L971E("1R97%U:7)E7VQI<W1[
M)&UO9'5L97T@?'P@9&\@>PIM>2`D:V5Y.PIF;W)E86-H("AK97ES("5R97%U
M:7)E7VQI<W0I('L*;F5X="!U;FQE<W,@+UQ1)&UO9'5L95Q%)"\["B1K97D@
M/2`D7SL@;&%S=#L*?0ID96QE=&4@)')E<75I<F5?;&ES='LD:V5Y?2!I9B!D
M969I;F5D*"1K97DI.PI](&]R(')E='5R;CL*)$E.0WLD;6]D=6QE?2`]("(O
M;&]A9&5R+R1F:6QE;F%M92\D;6]D=6QE(CL*:68@*"1%3E9[4$%27T-,14%.
M?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*;7D@)&9H(#T@24\Z
M.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I.PIP
M<FEN="`D9F@@)&9I;&5N86UE+3Y[8G5F?3L*<V5E:R@D9F@L(#`L(#`I.PIR
M971U<FX@)&9H.PI]"F5L<V4@>PIM>2`H)&]U="P@)&YA;64I(#T@7W1E;7!F
M:6QE*"<N<&TG+"`D9FEL96YA;64M/GMC<F-]*3L*:68@*"1O=70I('L*8FEN
M;6]D92@D;W5T*3L*<')I;G0@)&]U="`D9FEL96YA;64M/GMB=69].PIC;&]S
M92`D;W5T.PI]"F]P96X@;7D@)&9H+"`G/"<L("1N86UE(&]R(&1I92`D(3L*
M8FEN;6]D92@D9F@I.PIR971U<FX@)&9H.PI]"F1I92`B0F]O='-T<F%P<&EN
M9R!F86EL960Z(&-A;FYO="!F:6YD("1M;V1U;&4A7&XB.PI]+"!`24Y#*3L*
M<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E
M($-A<G`Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*4$%2.CI(
M96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PIR97%U:7)E($E/.CI&:6QE.PIW
M:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T
M*5LP72D@>PIU;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@
M/7X@+T)31%!!3B\I('L*:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2![
M"G)E<75I<F4@)&9I;&5N86UE.PI]"F5L<V4@>PID;R`D9FEL96YA;64@=6YL
M97-S("1F:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*?0I]"F1E
M;&5T92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["GT*;&%S="!U;FQE<W,@
M)&)U9B!E<2`B4$M<,#`S7#`P-"(["B1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I
M("T@-#L*?0IM>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G
M9F@L("1C86-H95]N86UE*3L*9&5L971E("1%3E9[4$%27T%04%]2155317T[
M(",@<V%N:71I>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI
M"B1Q=6EE="`](#`@=6YL97-S("1%3E9[4$%27T1%0E5'?3L*:68@*"$D<W1A
M<G1?<&]S(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI
M9G0I*2!["FUY("5D:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@
M(&EN<W1A;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV
M("`@=F5R:69Y7W!A<@HI.PII9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M
M+7)E=7-E)RD@>PIS:&EF="!`05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]
M('-H:69T($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U
M<@IM>2!`861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^
M("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E
M<2`G22<I('L*<'5S:"!`861D7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q
M("=-)RD@>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*
M=6YS:&EF="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*
M)&]U="`]("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S
M:71E)SL*?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*
M?0IE;'-I9B`H)#$@97$@)W$G*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q
M(&5Q("=,)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE(")86%@Z
M($-A;FYO="!O<&5N(&QO9SH@)"$B.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*
M)&-A8VAE7VYA;64@/2`D,CL*?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD
M(#T@)&1I<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*
M:6YI=%]I;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ
M)&-M9")]*"D@=6YL97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D
M7RD@9F]R($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O
M7VEN8SL*?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q
M=6ER92!!<F-H:79E.CI::7`["GT*;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*
M;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@>PI!<F-H:79E.CI::7`Z.G-E
M=$-H=6YK4VEZ92@Q,C@J,3`R-"D["F]P96X@;7D@)&9H+"`G/"<L("1P87(@
M;W(@9&EE(")#86YN;W0@9FEN9"`G)'!A<B<Z("0A(CL*8FEN;6]D92@D9F@I
M.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP
M+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@
M/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE(")296%D("<D<&%R
M)R!E<G)O<CH@)"$B.PI]"FUY("5E;G8@/2!D;R!["FEF("@D>FEP(&%N9"!M
M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B1M971A
M(#U^(',O+BI><&%R.B0O+VUS.PHD;65T82`]?B!S+UY<4RXJ+R]M<SL*)&UE
M=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PI]"GT["FQO8V%L("0O(#T@
M7#0["FEF("AD969I;F5D("1P87(I('L*;W!E;B!005(L("<\)RP@)'!A<B!O
M<B!D:64@(B0A.B`D<&%R(CL*8FEN;6]D92A005(I.PID:64@(B1P87(@:7,@
M;F]T(&$@4$%2(&9I;&4B('5N;&5S<R`\4$%2/B!E<2`B4$M<,#`S7#`P-"([
M"GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H
M"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]74D].
M3%DH*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@9&EE("0A
M.PIB:6YM;V1E*"1F:"D["B0O(#T@*&1E9FEN960@)&1A=&%?<&]S*2`_(%PD
M9&%T85]P;W,@.B!U;F1E9CL*<V5E:R!?1D@L(#`L(#`["FUY("1L;V%D97(@
M/2!S8V%L87(@/%]&2#X["FEF("@A)$5.5GM005)?5D520D%424U](&%N9"`D
M;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PIR97%U:7)E(%!!4CHZ1FEL
M=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P
M<&QY*%PD;&]A9&5R+"`D,"D*?0IF;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y
M<R`E96YV*2!["FUY("1V86P@/2`D96YV>R1K97E](&]R(&YE>'0["B1V86P@
M/2!E=F%L("1V86P@:68@)'9A;"`]?B`O7ELG(ETO.PIM>2`D;6%G:6,@/2`B
M7U]%3E9?4$%27R(@+B!U8R@D:V5Y*2`N(")?7R(["FUY("1S970@/2`B4$%2
M7R(@+B!U8R@D:V5Y*2`N("(])'9A;"(["B1L;V%D97(@/7X@<WLD;6%G:6,H
M("LI?7L*)&UA9VEC("X@)'-E="`N("@G("<@>"`H;&5N9W1H*"0Q*2`M(&QE
M;F=T:"@D<V5T*2DI"GUE9SL*?0HD9F@M/G!R:6YT*"1L;V%D97(I.PHD+R`]
M('5N9&5F.PII9B`H)&)U;F1L92D@>PIR97%U:7)E(%!!4CHZ2&5A=GD["E!!
M4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*:6YI=%]I;F,H*3L*<F5Q
M=6ER95]M;V1U;&5S*"D["FUY($!I;F,@/2!G<F5P('L@(2]"4T1004XO('T*
M9W)E<"!["B@D8G5N9&QE(&YE("=S:71E)RD@;W(**"1?(&YE("1#;VYF:6<Z
M.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*)%\@;F4@)$-O;F9I9SHZ0V]N9FEG
M>W!R:79L:6)E>'!]*3L*?2!`24Y#.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK
M*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU97,@
M)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T[
M"FUY("5W<FET=&5N.PIF;W)E86-H("AS;W)T(&ME>7,@)69I;&5S*2!["FUY
M("@D;F%M92P@)&9I;&4I.PIF;W)E86-H(&UY("1D:7(@*$!I;F,I('L*:68@
M*"1N86UE(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD7WTI('L*)&9I;&4@
M/2`D7SL*;&%S=#L*?0IE;'-I9B`H+UXH7%$D9&ER7$5<+R@N*EM>0V-=*2E<
M6B]I*2!["B@D9FEL92P@)&YA;64I(#T@*"0Q+"`D,BD["FQA<W0["GT*96QS
M:68@*&TA7B]L;V%D97(O6UXO72LO*"XJ6UY#8UTI7%HA*2!["FEF("AM>2`D
M<F5F(#T@)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R0Q?2D@>PHH)&9I;&4L
M("1N86UE*2`]("@D<F5F+"`D,2D["FQA<W0["GT*96QS:68@*"UF("(D9&ER
M+R0Q(BD@>PHH)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*;&%S
M=#L*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M92!A;F0@;F]T("1W
M<FET=&5N>R1N86UE?2LK.PIN97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL
M92`]?B`O7"Y<421L:6)?97AT7$4D+SL*;W5T<R@@:F]I;B`B(BP*<7$H4&%C
M:VEN9R`B*2P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE?2`Z("1F:6QE+`IQ
M<2@B+BXN*0HI.PIM>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL92DI('L*)&-O
M;G1E;G0@/2`D9FEL92T^>V)U9GT["GT*96QS92!["F]P96X@1DE,12P@)SPG
M+"`D9FEL92!O<B!D:64@(D-A;B=T(&]P96X@)&9I;&4Z("0A(CL*8FEN;6]D
M92A&24Q%*3L*)&-O;G1E;G0@/2`\1DE,13X["F-L;W-E($9)3$4["E!!4CHZ
M1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE
M*0II9B`A)$5.5GM005)?5D520D%424U](&%N9"`D;F%M92`]?B`O7"XH/SIP
M;7QI>'QA;"DD+VD["E!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0M/FYE=RT^
M87!P;'DH7"1C;VYT96YT+"`D9FEL92P@)&YA;64I.PI]"F]U=',H<7$H5W)I
M='1E;B!A<R`B)&YA;64B*2D["B1F:"T^<')I;G0H(D9)3$4B*3L*)&9H+3YP
M<FEN="AP86-K*"=.)RP@;&5N9W1H*"1N86UE*2`K(#DI*3L*)&9H+3YP<FEN
M="AS<')I;G1F*`HB)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-2
M0S,R*"1C;VYT96YT*2P@)&YA;64**2D["B1F:"T^<')I;G0H<&%C:R@G3B<L
M(&QE;F=T:"@D8V]N=&5N="DI*3L*)&9H+3YP<FEN="@D8V]N=&5N="D["GT*
M?0HD>FEP+3YW<FET951O1FEL94AA;F1L92@D9F@I(&EF("1Z:7`["B1C86-H
M95]N86UE(#T@<W5B<W1R("1C86-H95]N86UE+"`P+"`T,#L*:68@*"$D8V%C
M:&5?;F%M92!A;F0@;7D@)&UT:6UE(#T@*'-T870H)&]U="DI6SE=*2!["FUY
M("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T.CI3
M2$$M/FYE=R@Q*2!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@
M1&EG97-T.CI32$$Q+3YN97<@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z
M.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!].PIM>2`D<VAA7W9E<G-I;VX@/2!E
M=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*:68@*"1S:&%?
M=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@
M>PHD8W1X+3YA9&1F:6QE*"1O=70L(")B(BD@:68@*"1C='@I.PI]"F5L<V4@
M>PII9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\)&]U="(I*2!["F)I;FUO
M9&4H)&9H*3L*)&-T>"T^861D9FEL92@D9F@I.PIC;&]S92@D9F@I.PI]"GT*
M)&-A8VAE7VYA;64@/2`D8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE
M.PI]"B1C86-H95]N86UE("X](")<,"(@>"`H-#$@+2!L96YG=&@@)&-A8VAE
M7VYA;64I.PHD8V%C:&5?;F%M92`N/2`B0T%#2$4B.PHD9F@M/G!R:6YT*"1C
M86-H95]N86UE*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@)&9H+3YT96QL("T@
M;&5N9W1H*"1L;V%D97(I*2D["B1F:"T^<')I;G0H(EQN4$%2+G!M7&XB*3L*
M)&9H+3YC;&]S93L*8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@
M=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR
M97%U:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PI[
M"G)E<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*
M;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PIM>2`D9F@@/2!)3SHZ1FEL
M92T^;F5W.PHD9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@
M(B0A.B`D0"(["B1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G
M;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I(&]R(&1I92`B)"$Z("1`
M(CL*<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*)%!!4CHZ3&EB0V%C:&5[
M)'!R;V=N86UE?2`]("1Z:7`["B1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT[
M"F]U=',H<7$H7"1%3E9[4$%27U1%35!](#T@(B1%3E9[4$%27U1%35!](BDI
M.PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C('-H;W5L9"!B92!S
M970@870@=&AI<R!P;VEN="$*9F]R96%C:"!M>2`D;65M8F5R("@@)'II<"T^
M;65M8F5R<R`I('L*;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*;7D@
M)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA;64["FYE>'0@=6YL97-S
M("1M96UB97)?;F%M92`]?B!M>PI>"B\_<VAL:6(O"B@_.B1#;VYF:6<Z.D-O
M;F9I9WMV97)S:6]N?2\I/PHH/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]
M+RD_"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A8W1?;F%M92`]("0Q.PIM>2`D
M9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]414U0
M?2P@)&5X=')A8W1?;F%M92D["FEF("@M9B`D9&5S=%]N86UE("8F("US(%\@
M/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["F]U=',H<7$H4VMI
M<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@86QR96%D>2!E>&ES=',@
M870@(B1D97-T7VYA;64B*2D["GT@96QS92!["F]U=',H<7$H17AT<F%C=&EN
M9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M92(I*3L*)&UE;6)E<BT^
M97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I.PIC:&UO9"@P-34U+"`D
M9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B.PI]"GT*?0I]"G5N;&5S<R`H
M)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@>PID:64@/#P@(BXB('5N;&5S
M<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@
M+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R;V=R86TN<&P@70HD,"!;("U"
M?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN"B1%3E9[4$%27U!23T=.04U%
M?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H0$%21U8I.PI]"G-U8B!#<F5A
M=&50871H('L*;7D@*"1N86UE*2`]($!?.PIR97%U:7)E($9I;&4Z.D)A<V5N
M86UE.PIM>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E
M;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG*2D["G)E<75I<F4@1FEL
M93HZ4&%T:#L*1FEL93HZ4&%T:#HZ;6MP871H*"1P871H*2!U;FQE<W,H+64@
M)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@97)R;W(*?0IS=6(@<F5Q=6ER
M95]M;V1U;&5S('L*<F5Q=6ER92!L:6(["G)E<75I<F4@1'EN84QO861E<CL*
M<F5Q=6ER92!I;G1E9V5R.PIR97%U:7)E('-T<FEC=#L*<F5Q=6ER92!W87)N
M:6YG<SL*<F5Q=6ER92!V87)S.PIR97%U:7)E($-A<G`["G)E<75I<F4@0V%R
M<#HZ2&5A=GD["G)E<75I<F4@17)R;F\["G)E<75I<F4@17AP;W)T97(Z.DAE
M879Y.PIR97%U:7)E($5X<&]R=&5R.PIR97%U:7)E($9C;G1L.PIR97%U:7)E
M($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ4W!E8SL*<F5Q=6ER92!84TQO
M861E<CL*<F5Q=6ER92!#;VYF:6<["G)E<75I<F4@24\Z.DAA;F1L93L*<F5Q
M=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*<F5Q=6ER
M92!!<F-H:79E.CI::7`["G)E<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ2&5A
M=GD["G)E<75I<F4@4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0
M;V13=')I<#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PIR
M97%U:7)E(&%T=')I8G5T97,["F5V86P@>R!R97%U:7)E($-W9"!].PIE=F%L
M('L@<F5Q=6ER92!7:6XS,B!].PIE=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T
M:6P@?3L*979A;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T[
M"F5V86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T["F5V
M86P@>R!R97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!]
M.PIE=F%L('L@<F5Q=6ER92!U=&8X('T["GT*<W5B(%]S971?<&%R7W1E;7`@
M>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-
M4'T@/7X@+R@N*RDO*2!["B1P87)?=&5M<"`]("0Q.PIR971U<FX["GT*9F]R
M96%C:"!M>2`D<&%T:"`H"BAM87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2
M(%1-4$1)4B!414U01$E2(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@+W1M
M<"`N("D**2!["FYE>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P
M871H(&%N9"`M=R`D<&%T:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U:60["F5V
M86P@>R@D<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*
M:68@*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N86UE
M(#T@)E=I;C,R.CI,;V=I;DYA;64["GT*96QS:68@*&1E9FEN960@)'!W=6ED
M*2!["B1U<V5R;F%M92`]("1P=W5I9#L*?0IE;'-E('L*)'5S97)N86UE(#T@
M)$5.5GM54T523D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*?0HD
M=7-E<FYA;64@/7X@<R]<5R]?+V<["FUY("1S=&UP9&ER(#T@(B1P871H)$-O
M;F9I9WM?9&5L:6U]<&%R+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D["FUK
M9&ER("1S=&UP9&ER+"`P-S4U.PII9B`H(21%3E9[4$%27T-,14%.?2!A;F0@
M;7D@)&UT:6UE(#T@*'-T870H)'!R;V=N86UE*2E;.5TI('L*;W!E;B`H;7D@
M)&9H+"`B/"(N("1P<F]G;F%M92D["G-E96L@)&9H+"`M,3@L(#(["G-Y<W)E
M860@)&9H+"!M>2`D8G5F+"`V.PII9B`H)&)U9B!E<2`B7#!#04-(12(I('L*
M<V5E:R`D9F@L("TU."P@,CL*<WES<F5A9"`D9F@L("1B=68L(#0Q.PHD8G5F
M(#U^(',O7#`O+V<["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H
M92TB("X@)&)U9CL*?0IE;'-E('L*;7D@)&-T>"`](&5V86P@>R!R97%U:7)E
M($1I9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(02T^;F5W*#$I('T*?'P@979A;"![
M(')E<75I<F4@1&EG97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"GQ\
M(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W
M('T["FUY("1S:&%?=F5R<VEO;B`](&5V86P@>R`D1&EG97-T.CI32$$Z.E9%
M4E-)3TX@?2!\?"`P.PII9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D
M<VAA7W9E<G-I;VX@97$@)S4N,SDG*2!["B1C='@M/F%D9&9I;&4H)'!R;V=N
M86UE+"`B8B(I(&EF("@D8W1X*3L*?0IE;'-E('L*:68@*"1C='@@86YD(&]P
M96XH;7D@)&9H+"`B/"1P<F]G;F%M92(I*2!["F)I;FUO9&4H)&9H*3L*)&-T
M>"T^861D9FEL92@D9F@I.PIC;&]S92@D9F@I.PI]"GT*)'-T;7!D:7(@+CT@
M(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`H("1C='@@/R`D8W1X+3YH97AD
M:6=E<W0@.B`D;71I;64@*3L*?0IC;&]S92@D9F@I.PI]"F5L<V4@>PHD14Y6
M>U!!4E]#3$5!3GT@/2`Q.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]
M=&5M<"TD)"(["GT*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;6MD:7(@
M)'-T;7!D:7(L(#`W-34["FQA<W0["GT*)'!A<E]T96UP(#T@)#$@:68@)$5.
M5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0IS
M=6(@7W1E;7!F:6QE('L*;7D@*"1E>'0L("1C<F,I(#T@0%\["FUY("@D9F@L
M("1F:6QE;F%M92D["B1F:6QE;F%M92`]("(D<&%R7W1E;7`O)&-R8R1E>'0B
M.PII9B`H)$5.5GM005)?0TQ%04Y]*2!["G5N;&EN:R`D9FEL96YA;64@:68@
M+64@)&9I;&5N86UE.PIP=7-H($!T;7!F:6QE+"`D9FEL96YA;64["GT*96QS
M92!["G)E='5R;B`H=6YD968L("1F:6QE;F%M92D@:68@*"UR("1F:6QE;F%M
M92D["GT*;W!E;B`D9F@L("<^)RP@)&9I;&5N86UE(&]R(&1I92`D(3L*8FEN
M;6]D92@D9F@I.PIR971U<FXH)&9H+"`D9FEL96YA;64I.PI]"G-U8B!?<V5T
M7W!R;V=N86UE('L*:68@*&1E9FEN960@)$5.5GM005)?4%)/1TY!345](&%N
M9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2!["B1P<F]G;F%M92`]
M("0Q.PI]"B1P<F]G;F%M92!\?#T@)#`["FEF("@D14Y6>U!!4E]414U0?2!A
M;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@>PHD
M<')O9VYA;64@/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N86UE
M+"`D0V]N9FEG>U]D96QI;7TI("L@,2D["GT*:68@*"$D14Y6>U!!4E]04D]'
M3D%-17T@;W(@:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#X]
M(#`I('L*:68@*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@>PIR971U
M<FX@:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N86UE)$-O;F9I9WM?97AE
M?2(I('L*)'!R;V=N86UE("X]("1#;VYF:6=[7V5X97T["G)E='5R;CL*?0I]
M"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)$-O;F9I9WMP871H7W-E<'U<
M12\L("1%3E9[4$%42'TI('L*;F5X="!I9B!E>&ES=',@)$5.5GM005)?5$5-
M4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B1D:7(@/7X@<R]<421#
M;VYF:6=[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I
M9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(I+"!L87-T*0II9B`M
M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB
M.PHH*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE
M(BDL(&QA<W0I"FEF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE
M(CL*?0I]"G-U8B!?9FEX7W!R;V=N86UE('L*)#`@/2`D<')O9VYA;64@?'P]
M("1%3E9[4$%27U!23T=.04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M92P@)$-O
M;F9I9WM?9&5L:6U]*2`\(#`I('L*)'!R;V=N86UE(#T@(BXD0V]N9FEG>U]D
M96QI;7TD<')O9VYA;64B.PI]"FUY("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG
M971C=V0I(#\@0W=D.CIG971C=V0H*0HZ("@H9&5F:6YE9"`F5VEN,S(Z.D=E
M=$-W9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D["F-H;VUP*"1P=V0I
M.PHD<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421#;VYF:6=[7V1E;&EM?5Q%
M*2\D<'=D)$-O;F9I9WM?9&5L:6U]+SL*)$5.5GM005)?4%)/1TY!345](#T@
M)'!R;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?96YV('L*:68@*"`D14Y6>U!!
M4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PIR971U<FX["GT@96QS92!["B1%
M3E9[4$%27TE.251)04Q)6D5$?2`](#(["GT*9F]R("AQ=R@@4U!!5TY%1"!4
M14U0($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%($%21T,@05)'5E\P("D@
M*2!["F1E;&5T92`D14Y6>R=005)?)RXD7WT["GT*9F]R("AQ=R\@5$U01$E2
M(%1%35`@0TQ%04X@1$5"54<@+RD@>PHD14Y6>R=005)?)RXD7WT@/2`D14Y6
M>R=005)?1TQ/0D%,7R<N)%]](&EF(&5X:7-T<R`D14Y6>R=005)?1TQ/0D%,
M7R<N)%]].PI]"FUY("1P87)?8VQE86X@/2`B7U]%3E9?4$%27T-,14%.7U\@
M("`@("`@("`@("`@("`B.PII9B`H)$5.5GM005)?5$5-4'TI('L*9&5L971E
M("1%3E9[4$%27T-,14%.?3L*?0IE;'-I9B`H(65X:7-T<R`D14Y6>U!!4E]'
M3$]"04Q?0TQ%04Y]*2!["FUY("1V86QU92`]('-U8G-T<B@D<&%R7V-L96%N
M+"`Q,B`K(&QE;F=T:"@B0TQ%04XB*2D["B1%3E9[4$%27T-,14%.?2`]("0Q
M(&EF("1V86QU92`]?B`O7E!!4E]#3$5!3CTH7%,K*2\["GT*?0IS=6(@;W5T
M<R!["G)E='5R;B!I9B`D<75I970["FEF("@D;&]G9F@I('L*<')I;G0@)&QO
M9V9H(")`7UQN(CL*?0IE;'-E('L*<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN
M:71?:6YC('L*<F5Q=6ER92!#;VYF:6<["G!U<V@@0$E.0RP@9W)E<"!D969I
M;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@
M<')I=FQI8F5X<"!S:71E87)C:&5X<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE
M>'`@=F5N9&]R;&EB97AP"BD["GT*<&%C:V%G92!M86EN.PIR97%U:7)E(%!!
M4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T
M*$!P87)?87)G<RD["F1I92!Q<2AP87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S
M8W)I<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<
M;BD*=6YL97-S("UE("1P<F]G;F%M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE
M>&ET*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@
M)$`@:68@)$`["GT["B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE
M>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>7U1+7T58251?7"@H7&0K*5PI
M+RD["F1I92`D.CI?7T524D]2(&EF("0Z.E]?15)23U(["C$["E]?14Y$7U\*
M`````````````````````````,!#`1L#.\0````7````0(K__^````!PB___
M"`$``+"+__\@`0``H*'__U`!``"`HO__>`$``-"B__^8`0``\*+__[`!``!`
MH___R`$``)"D___H`0``$*7__P`"``#@I?__(`(``/"E__\X`@``$*C__W`"
M```PJ?__J`(``/"J___``@``(*O__]@"```0K/__^`(``("L__\0`P``H*[_
M_S`#``!PL/__:`,``+"Z__^@`P``<+[__]@#``"@OO__\`,````````4````
M``````%Z4@`!>!`!`PP'")`!```D````'````-`=0`"R`````$$.$(8"0PT&
M0HT#2X,%C`0`````````%````$0`````'T``-```````````````+````%P`
M``!`'T``\!4```!"#A!&#AA"#B!!#BB&!8P$C0..`D0.,$<.N`2#!@``)```
M`(P````P-4``V0````!*CP*,!5X.0(X#C02&!H,'`````````!P```"T````
M$#9``$\`````00X000X8@P.&`D<.,```%````-0```!@-D``%0````!$#B``
M````%````.P```"`-D``30````!$#A``````'`````0!``#0-D``0@$```!*
M@P:,!%D.L`&.`HT#A@44````)`$``"`X0`!Y`````$$.$(,"```<````/`$`
M`*`X0`#)`````%8.P!",`H8#@P0``````!0```!<`0``<#E```4`````````
M`````#0```!T`0``@#E``!4"````0@X01`X8C@./`D4.($(.*$$.,(8&C`6-
M!$0..$0.4(,'````````-````*P!``"@.T``%P$```!"#A!"#AB.`X\"10X@
M0@XHC`6-!$<.,$$..$0.@`&#!X8&```````4````Y`$``,`\0`"^`0```$0.
M0``````4````_`$``(`^0``B`````$0.$``````<````%`(``+`^0`#B````
M`$$.$$$.&(,#A@)'#B```!0````T`@``H#]``&T`````3@X@A@*#`QP```!,
M`@``$$!``!@"````00X01`XP@P(`````````-````&P"```P0D``Q@$```!"
M#A!"#AA"#B!"#BB,!8T$C@./`DD.,$$..(,'A@9*#N`(```````T````I`(`
M``!$0``^"@```$(.$(\"2@X80@X@0@XH00XP00XX1PZ@@P*#!X8&C`6-!(X#
M`````#0```#<`@``0$Y``,`#````0@X00@X80@X@0@XH00XP00XX1P[0"(,'
MA@:,!8T$C@./`@``````%````!0#````4D``*@````!$#A``````%````"P#
M```P4D``1`````!$#A``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````/__________``````````#__________P``````````````
M```````!``````````$``````````0````````!<``````````$`````````
MXP$````````!`````````.T!`````````0````````#[`0````````$`````
M````"`(````````/`````````#$#````````'0`````````Q`P````````P`
M````````R!E````````-`````````+120```````!``````````P`D``````
M`/7^_V\`````N`1````````%`````````$@.0```````!@````````"H!4``
M``````H`````````.00````````+`````````!@`````````%0``````````
M``````````,`````````.*)@```````"`````````-`%````````%```````
M```'`````````!<`````````^!-````````'`````````(`30```````"```
M``````!X``````````D`````````&`````````#^__]O`````$`30```````
M____;P`````"`````````/#__V\`````@A)`````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````HH&``````
M``````````````````````#R&4````````(:0```````$AI````````B&D``
M`````#(:0```````0AI```````!2&D```````&(:0```````<AI```````""
M&D```````)(:0```````HAI```````"R&D```````,(:0```````TAI`````
M``#B&D```````/(:0````````AM````````2&T```````"(;0```````,AM`
M``````!"&T```````%(;0```````8AM```````!R&T```````((;0```````
MDAM```````"B&T```````+(;0```````PAM```````#2&T```````.(;0```
M````\AM````````"'$```````!(<0```````(AQ````````R'$```````$(<
M0```````4AQ```````!B'$```````'(<0```````@AQ```````"2'$``````
M`*(<0```````LAQ```````#"'$```````-(<0```````XAQ```````#R'$``
M``````(=0```````$AU````````B'4```````#(=0```````0AU```````!2
M'4```````&(=0```````<AU```````""'4```````)(=0```````HAU`````
M``"R'4```````,(=0```````851``````````````````!B@8````````%9`
M``````#_____`"1&<F5E0E-$.B!R96QE87-E+SDN,BXP+VQI8B]C<W4O86UD
M-C0O8W)T,2YC(#(T-3<W-R`R,#$S+3`Q+3(R(#`W.C,R.C(V6B!K:6(@)``D
M1G)E94)31#H@<F5L96%S92\Y+C(N,"]L:6(O8W-U+V-O;6UO;B]C<G1B<F%N
M9"YC(#(Q-S,W-2`R,#$Q+3`Q+3$S(#(P.C0T.C,Q6B!D:6T@)`!'0T,Z("A'
M3E4I(#0N,BXQ(#(P,#<P.#,Q('!A=&-H960@6T9R965"4T1=```D1G)E94)3
M1#H@<F5L96%S92\Y+C(N,"]L:6(O8W-U+V%M9#8T+V-R=&DN4R`R,3<Q,#4@
M,C`Q,2TP,2TP-R`Q-CHP-SHU,5H@:VEB("0``$=#0SH@*$=.52D@-"XR+C$@
M,C`P-S`X,S$@<&%T8VAE9"!;1G)E94)31%T``$=#0SH@*$=.52D@-"XR+C$@
M,C`P-S`X,S$@<&%T8VAE9"!;1G)E94)31%T``$=#0SH@*$=.52D@-"XR+C$@
M,C`P-S`X,S$@<&%T8VAE9"!;1G)E94)31%T``"1&<F5E0E-$.B!R96QE87-E
M+SDN,BXP+VQI8B]C<W4O86UD-C0O8W)T;BY3(#(Q-S$P-2`R,#$Q+3`Q+3`W
M(#$V.C`W.C4Q6B!K:6(@)```+G-H<W1R=&%B`"YI;G1E<G``+FYO=&4N04))
M+71A9P`N9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R`"YG;G4N=F5R<VEO;@`N
M9VYU+G9E<G-I;VY?<@`N<F5L82YD>6X`+G)E;&$N<&QT`"YI;FET`"YT97AT
M`"YF:6YI`"YR;V1A=&$`+F5H7V9R86UE7VAD<@`N96A?9G)A;64`+F-T;W)S
M`"YD=&]R<P`N:F-R`"YD>6YA;6EC`"YG;W0N<&QT`"YD871A`"YB<W,`+F-O
M;6UE;G0`````````````````````````````````````````````````````
M```````````````````````````````````````````+`````0````(`````
M``````)``````````@```````!4````````````````````!````````````
M````````$P````<````"`````````!@"0```````&`(````````8````````
M````````````!````````````````````"4````%`````@`````````P`D``
M`````#`"````````A`(````````%``````````@`````````!``````````A
M````]O__;P(`````````N`1```````"X!````````/``````````!0``````
M```(````````````````````*P````L````"`````````*@%0```````J`4`
M``````"@"`````````8````!````"``````````8`````````#,````#````
M`@````````!(#D```````$@.````````.00```````````````````$`````
M```````````````[````____;P(`````````@A)```````""$@```````+@`
M````````!0`````````"``````````(`````````2````/[__V\"````````
M`$`30```````0!,```````!```````````8````"````"```````````````
M`````%<````$`````@````````"`$T```````(`3````````>``````````%
M``````````@`````````&`````````!A````!`````(`````````^!-`````
M``#X$P```````-`%````````!0````P````(`````````!@`````````:P``
M``$````&`````````,@90```````R!D````````3````````````````````
M!````````````````````&8````!````!@````````#<&4```````-P9````
M````\`,```````````````````0`````````$`````````!Q`````0````8`
M````````T!U```````#0'0```````.0T```````````````````0````````
M````````````=P````$````&`````````+120```````M%(````````.````
M````````````````!````````````````````'T````!`````@````````#(
M4D```````,A2````````R$````````````````````@`````````````````
M``"%`````0````(`````````D)-```````"0DP```````,0`````````````
M```````$````````````````````DP````$````"`````````%B40```````
M6)0```````!$`P``````````````````"````````````````````)T````!
M`````P``````````H&````````"@````````$`````````````````````@`
M``````````````````"D`````0````,`````````$*!@```````0H```````
M`!`````````````````````(````````````````````JP````$````#````
M`````""@8```````(*`````````(````````````````````"```````````
M`````````+`````&`````P`````````HH&```````"B@````````$`(`````
M```&``````````@`````````$`````````"Y`````0````,`````````.*)@
M```````XH@````````@"```````````````````(``````````@`````````
MP@````$````#`````````$"D8```````0*0````````D````````````````
M````"````````````````````,@````(`````P````````"`I&```````&2D
M````````"`4``````````````````"````````````````````#-`````0``
M``````````````````````!DI````````/<!```````````````````!````
M`````````````````0````,`````````````````````````6Z8```````#6
?`````````````````````0``````````````````````
